@@ -11,9 +11,12 @@ from  _pyfmtools import ffi, lib as fm
 # Helper functions
 ###
 
+# global variable to support trace-info while testing
+isTest = False
+
 # Trace function
 def trace( str):
-    print( "-- ", str, " --")
+    if isTest == True: print( "-- ", str, " --")
 
 
 # convert Python float to CFFI double * 
@@ -325,7 +328,7 @@ def ConstructLambdaMeasureMob(singletons, env):
 def dualm(v, env):
     trace( "void py_dualm(double* v, double* out_w, struct fm_env* env)")
     pvnp, pv = convert_py_float_to_cffi( v)
-    pout_wnp, pout_w = create_float_zeros_as_CFFI_double( env.n)
+    pout_wnp, pout_w = create_float_zeros_as_CFFI_double( env.m)
     fm.py_dualm( pv, pout_w, env)
     return pout_wnp
 
@@ -335,7 +338,7 @@ def dualm(v, env):
 def dualmMob(v, env):
     trace( "void py_dualmMob(double* v, double* out_w, struct fm_env* env)")
     pvnp, pv = convert_py_float_to_cffi( v)
-    pout_wnp, pout_w = create_float_zeros_as_CFFI_double( env.n)
+    pout_wnp, pout_w = create_float_zeros_as_CFFI_double( env.m)
     fm.py_dualmMob( pv, pout_w, env)
     return pout_wnp
 
@@ -502,7 +505,7 @@ def Interaction(v, env):
     trace( "void py_Interaction(double* out_Mob, double* v, struct fm_env* env)")
     pout_Mobnp, pout_Mob = create_float_zeros_as_CFFI_double( env.m)
     pvnp, pv = convert_py_float_to_cffi( v)
-    fm.py_Interaction( pout_Mobpv, env)
+    fm.py_Interaction( pout_Mob, pv, env)
     return pout_Mobnp
 
 
@@ -512,7 +515,7 @@ def InteractionB(v, env):
     trace( "void py_InteractionB(double* out_Mob, double* v, struct fm_env* env)")
     pout_Mobnp, pout_Mob = create_float_zeros_as_CFFI_double( env.m)
     pvnp, pv = convert_py_float_to_cffi( v)
-    fm.py_InteractionB( pout_Mobpv, env)
+    fm.py_InteractionB( pout_Mob, pv, env)
     return pout_Mobnp
 
 
@@ -522,7 +525,7 @@ def InteractionMob(v, env):
     trace( "void py_InteractionMob(double* out_Mob, double* v, struct fm_env* env)")
     pout_Mobnp, pout_Mob = create_float_zeros_as_CFFI_double( env.m)
     pvnp, pv = convert_py_float_to_cffi( v)
-    fm.py_InteractionMob( pout_Mobpv, env)
+    fm.py_InteractionMob( pout_Mob, pv, env)
     return pout_Mobnp
 
 
@@ -811,11 +814,12 @@ def Zeta(Mob, env):
 
 # Generated python wrapper for:
 #    void py_dualMobKadd(int m, int length, int k, double* src, double* out_dest, struct fm_env* env)
-def dualMobKadd(m, length, k, src, env):
+def dualMobKadd(k, src, env):
     trace( "void py_dualMobKadd(int m, int length, int k, double* src, double* out_dest, struct fm_env* env)")
     psrcnp, psrc = convert_py_float_to_cffi( src)
     pout_destnp, pout_dest = create_float_zeros_as_CFFI_double( env.m)
-    fm.py_dualMobKadd( m, length, k, psrc, pout_dest, env)
+    length = fm.py_fm_arraysize( env.n, k, env)
+    fm.py_dualMobKadd( env.m, length, k, psrc, pout_dest, env)
     return pout_destnp
 
 
@@ -824,7 +828,7 @@ def dualMobKadd(m, length, k, src, env):
 def Shapley2addMob(v, n):
     trace( "void py_Shapley2addMob(double* v, double* out_x, int n)")
     pvnp, pv = convert_py_float_to_cffi( v)
-    pout_xnp, pout_x = create_float_zeros_as_CFFI_double( env.m)
+    pout_xnp, pout_x = create_float_zeros_as_CFFI_double( n)
     fm.py_Shapley2addMob( pv, pout_x, n)
     return pout_xnp
 
@@ -834,7 +838,7 @@ def Shapley2addMob(v, n):
 def Banzhaf2addMob(v, n):
     trace( "void py_Banzhaf2addMob(double* v, double* out_x, int n)")
     pvnp, pv = convert_py_float_to_cffi( v)
-    pout_xnp, pout_x = create_float_zeros_as_CFFI_double( env.m)
+    pout_xnp, pout_x = create_float_zeros_as_CFFI_double( n)
     fm.py_Banzhaf2addMob( pv, pout_x, n)
     return pout_xnp
 
